function Dsim = DsimOrder(X,Y,M,t)

%  DsimOrder  Calculate the Dissimilarity index based on order pattern
%  analysis
%
%  Input:   X,Y: 1xN time series;
%           M: the embedding dimension (common M=3,4 or 5)
%           t: delay time of permuation entropy, 
%
% Output: 
%           Dsim: Dissimilarity index
% Example
% M = 4;
% t=1;
% X = sin(0.1:0.1:1000);
% X = 1:10000;
% Y = randn(1,10000);
% OPx = peprobc(X,M,t,0) ;
% OPy = peprobc(Y,M,t,0) ;
% Dsim = DsimOrder(X,Y,M,t)
% figure(1)
% plot(sort(OPx), 'r-x')
% hold on 
% plot(sort(OPy), '-o')
%
% Ref: Ouyang, G., et al. (2010). "Ordinal pattern based similarity analysis for EEG recordings." Clin Neurophysiol 121(5): 694-703.

% revise time: Dec 18 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli


OPx = peprobc(X,M,t,0) ;
OPy = peprobc(Y,M,t,0) ;
Dsim = DsimO(OPx,OPy);

function Dsim = DsimO(OPx,OPy)
% DsimO  dissimilarity estimate.
% Output
% Dsim - Dissimilarity index
% Input
% OPx - probability distribution of order patterns from time series x
% OPy - probability distribution of order patterns from time series y

Px=OPx/sum(OPx);
Py=OPy/sum(OPy);
L=length(OPx);
    
Px = sort(Px);
Py = sort(Py);

Dsim = (L/(L-1))^0.5*(sum((Px-Py).^2))^0.5;  % % normalized (Dsim: 0 - 1)
 