function PE = ENTR(OPx)

% ENTR  Entropy estimate.
% Output
% PE - normalized permutation entropy
% Input
% OPx - probability distribution of order patterns from time series x
% Example
% M = 4;
% t=1;
% threadhold = 0;
% x = randn(1,1000);
% OPx = peprobc(x,M,t,threadhold);
% PE = PEOrder(OPx)
%
% referrence: 
% Bandt, C. and B. Pompe (2002). "Permutation entropy: a natural complexity measure for time series." Phys Rev Lett 88(17): 174102.
%
%  revise time: Dec 18 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli

Px=OPx/sum(OPx);
L=length(OPx);

PE = 0;
for i=1:L
    if Px(i) >0;
        PE = PE - Px(i)*log(Px(i));
    end
end
PE = PE/log(L);  % normalized (PE: 0 - 1)

