function MPE = MPermEn(X,M,t,Scale)

%  MPermEn  Calculate the Multiscale Permutation Entropy (MPE)
%
%  Input:   X: time series;
%           M: the embedding dimension (common M=3,4 or 5)
%           t: delay time of permuation entropy, 
%           Scale: the scale factor
%
% Output: 
%           MPE: multiscale permuation entropy
% Example
% M = 4;
% t=1;
% Scale = 10;
% X = sin(0.1:0.1:200);
% MPE = MPermEn(X,M,t,Scale);
% plot([1:Scale],MPE)

%Ref: G Ouyang, J Li, X Liu, X Li, Dynamic Characteristics of Absence EEG Recordings with Multiscale Permutation Entropy Analysis, Epilepsy Research, doi: 10.1016/j.eplepsyres.2012.11.003
%     G Ouyang, C Dang, X Li, Complexity Analysis of EEG Data with Multiscale Permutation Entropy, Advances in Cognitive Neurodynamics (II), 2011, pp 741-745 
% revise time: Dec 18 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli


MPE=[];
for j=1:Scale
    Xs = Multi(X,j);
    PE = PermEn(Xs,M,t,0);
    MPE=[MPE PE];
end


function M_Data = Multi(Data,S)

%  generate the consecutive coarse-grained time series
%  Input:   Data: time series;
%           S: the scale factor

% Output: 
%           M_Data: the coarse-grained time series at the scale factor S

L = length(Data);
J = fix(L/S);

for i=1:J
    M_Data(i) = mean(Data((i-1)*S+1:i*S));
end


