function [Dxy,Ixy,Iyx] = PCMIc(X,Y,t,tau)

%  PCMIc  Permutation Conditional Mutual Informaion
%  Input:   X, Y time series;
%           t: delay time of order pattern analysis, default t=1
%           tau: delay time in conditional mutual information
%
%           order: dimension of order pattern analysis (In this code, parameter order is set to 3.)  
%                  ord!*ord!*ord!<N, N is length of series X and Y:
%
% Output: 
%           Ixy:  conditional mutual informaion (I(X,Dy|Y)) ;
%           Ixy:  conditional mutual informaion (I(Y,Dy|X)) ;
%           Dxy:  The direcionality of the coupling between the X and Y, X->Y; 
%                     if Out.Dxy > 0, means X->Y, otherwise X<-Y; 
%
%% referrence: Estimating coupling direction between neuronal populations
%% with permutation conditional mutual information, NeuroImage, 2010, 52:497-507 
%
% Z = sin(0.1:0.1:220);
% x = Z(1:2000);
% y = Z(21:2020) + 0.1*randn(1,2000);
% t =1;
% tau = 5;
% [Dxy,Ixy,Iyx] = PCMIc(x,y,t,tau)

%  revise time: Dec 18 2012, Yan, Jiaqing, Ouyang, Gaoxiang and Li, Xiaoli 


DeltaX = X((1+tau):end);
DeltaY = Y((1+tau):end);

X1 = X(1:(end-tau));
Y1 = Y(1:(end-tau));

Ixy = pecmi(X1,DeltaY, Y1,t);
Iyx = pecmi(Y1,DeltaX, X1,t);

Dxy=0;
if Ixy~=0
    Dxy=(Ixy-Iyx)/(Ixy+Iyx);
end
