function [Dxy,Ixy,Iyx] = PCMIc_tau_win(X,Y,win,overlap,t,Tau)

%  Calculate the CMI using the moving window technique.

%  Input:   X, Y time series;
%           win: length of window
%           order: order of permuation entropy, ord!*ord!*ord!<N, N is length of series X and Y:
%           t: delay time of permuation entropy, default t=1

%           Tau: delay time in conditional mutual information

% Output: 
%           Ixym:  conditional mutual informaion (I(X,Dy|Y)) ;
%           Ixym:  conditional mutual informaion (I(Y,Dy|X)) ;

%           Dxym:  The direcionality of the coupling between the X and Y, X->Y; 
%                     if Out.Dxy > 0, means X->Y, otherwise X<-Y; 
          

%% referrence: Estimating coupling direction between neuronal populations
%% with permutation conditional mutual information, NeuroImage, 2010,52:497-507 

%  revise time: Jun 4 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli


w=win;

L=min([length(X), length(Y)]);
I=1+fix((L-w)/(w-overlap));



for i=1:I
    Xw=X((i-1)*(w-overlap)+1:(i-1)*(w-overlap)+w);
    Yw=Y((i-1)*(w-overlap)+1:(i-1)*(w-overlap)+w);
    
    for j = 1:length(Tau);     
        [Dxy(i,j),Ixy(i,j),Iyx(i,j)] = CMIc(Xw,Yw,t,Tau(j));
     end
     fprintf('wait')
end

