function [MDxy,MIxy,MIyx, Dxy,Ixy,Iyx] = PCMImc_tau_win(X,win,overlap,t,Tau)

%  Calculate the CMI using the moving window technique.

%  Input:   X: time series  n x N;
%           win: length of window
%           t: delay time of permuation entropy, default t=1

%           Tau: delay time in conditional mutual information

% Output: 
%           Ixym:  conditional mutual informaion (I(X,Dy|Y)) ;
%           Ixym:  conditional mutual informaion (I(Y,Dy|X)) ;

%           Dxym:  The direcionality of the coupling between the X and Y, X->Y; 
%                     if Out.Dxy > 0, means X->Y, otherwise X<-Y; 
          

%% referrence: Estimating coupling direction between neuronal populations
%% with permutation conditional mutual information, NeuroImage, 2010,52:497-507 

%  revise time: Jun 4 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli

if size(X,1) > size(X,2)
    X = X';
end

w=win;

n = size(X,1);
L = size(X,2);
I=1+fix((L-w)/(w-overlap));



for ii=1:I
    Xw=X(:,(ii-1)*(w-overlap)+1:(ii-1)*(w-overlap)+w);
    
    for i = 1:n-1
        for j = i+1:n
            for jj = 1:length(Tau);
                [Dxy1(jj),Ixy1(jj),Iyx1(jj)] = CMIc(Xw(i,:),Xw(j,:),t,Tau(jj));
            end
            Dxy{ii,i,j} = Dxy1;
            Ixy{ii,i,j} = Ixy1;
            Iyx{ii,i,j} = Iyx1;
            
            MDxy(ii,i,j) = (mean(Ixy1) - mean(Iyx1)) / (mean(Ixy1) + mean(Iyx1));
            MDxy(ii,j,i) = - (mean(Ixy1) - mean(Iyx1)) / (mean(Ixy1) + mean(Iyx1));      
            
            MIxy(ii,i,j) = mean(Ixy1);
            MIxy(ii,j,i) = mean(Iyx1);
            
            MIyx(ii,j,i) = mean(Ixy1);
            MIyx(ii,i,j) = mean(Iyx1);
        end
    end
    fprintf('wait')
end


