function PE = PermEn(y,M,t,threadhold)

% PermEn Permutation entropy estimate.
% Output
% PE - normalized permutation entropy
%
% Input
% y - 1xN time series
% M is the embedding dimension (order pattern) (common M=3,4,5 or 6)
% t is the delay time (Default t=1)
% threadhold - the threshold value (Default 0)
%
% Example
% M = 8;
% t=1;
% threadhold = 0;
% y = randn(1,100000);
% PE = PermEn(y,M,t,threadhold)

% referrence: 
% Bandt, C. and B. Pompe (2002). "Permutation entropy: a natural complexity measure for time series." Phys Rev Lett 88(17): 174102.
%
% revise time: Dec 18 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli


peprob = peprobc(y,M,t,threadhold) ;
PE = ENTR(peprob);     % normalized (PE: 0 - 1)

