function peprob = peprobc(y,M,t,threadhold)

% peprobc Probability distribution estimate.
% Output
% peprob - probability distribution of order patterns
%
% Input
% y - 1xN time series
% M is the embedding dimension (common M=3,4,5 or 6)
% t is the delay time (Default t=1)
% threadhold - the threshold value (Default 0)
%
% Example
% M = 3;
% t=1;
% threadhold = 0;
% y = randn(1,1000);
% peprob1 = peprobc(y,M,t,threadhold);
% subplot(121)
% bar(peprob1)
% title('order patters of noise')
% y = sin([0.1:0.1:100]);
% peprob2 = peprobc(y,M,t,threadhold);
% subplot(122)
% bar(peprob2)
% title('order patters of sine time series')

% referrence: 
% Bandt, C. and B. Pompe (2002). "Permutation entropy: a natural complexity measure for time series." Phys Rev Lett 88(17): 174102.
%
%  revise time: Dec 18 2012, Yan, Jiaqing; Ouyang, Gaoxiang and Li, Xiaoli


if ~exist('M')|isempty(M),M=3;end
if ~exist('t')|isempty(t),t=1;end
if ~exist('threadhold')|isempty(threadhold),threadhold=0;end


if ~libisloaded('peproblib')
    loadlibrary('peprob','peprob.h','alias','peproblib');
    calllib('peproblib', 'InitPEProb', M);
end

if calllib('peproblib', 'GetMotifs')~=M
    calllib('peproblib','ReleasePEProb');
    calllib('peproblib', 'InitPEProb', M);
end

y_ary = libpointer('doublePtr',y);

prob_ary=calllib('peproblib','PEProb',y_ary,length(y),t,threadhold);

setdatatype(prob_ary, 'int32Ptr', 1,  factorial(M));
peprobstr=get(prob_ary);
peprob=peprobstr.Value; 

peprob = double(peprob);

